/*
 * Copyright (c) 2007 Extreme! Lab, Indiana University. All rights reserved.
 *
 * This software is open source. See the bottom of this file for the license.
 *
 * $Id: 
 */
package edu.indiana.extreme.xbaya.component.registry;

import java.net.URI;
import java.util.List;

import xsul.wsdl.WsdlDefinitions;
import xsul.wsdl.WsdlResolver;
import edu.indiana.extreme.xbaya.component.ComponentException;
import edu.indiana.extreme.xbaya.component.gui.ComponentTreeNode;
import edu.indiana.extreme.xbaya.component.ws.WSComponent;
import edu.indiana.extreme.xbaya.component.ws.WSComponentFactory;
import edu.indiana.extreme.xbaya.util.WSDLUtil;

/**
 * @author Satoshi Shirasuna
 */
public class URLComponentRegistry extends ComponentRegistry {

    // private static final MLogger logger = MLogger.getLogger();

    private ComponentTreeNode tree;

    private URI url;

    /**
     * Creates a URLComponentRegistry
     * 
     * @param url
     */
    public URLComponentRegistry(URI url) {
        this.url = url;
        this.tree = new ComponentTreeNode(this);
    }

    /**
     * @see edu.indiana.extreme.xbaya.component.registry.ComponentRegistry#getName()
     */
    @Override
    public String getName() {
        return "" + this.url;
    }

    /**
     * @throws ComponentRegistryException
     * @see edu.indiana.extreme.xbaya.component.registry.ComponentRegistry#getComponentTree()
     */
    @Override
    public ComponentTreeNode getComponentTree()
            throws ComponentRegistryException {
        this.tree = new ComponentTreeNode(this);
        try {
            loadComponents();
            return this.tree;
        } catch (ComponentException e) {
            throw new ComponentRegistryException(e);
        }
    }

    /**
     * @return The tree.
     */
    public ComponentTreeNode getComponentTreeWithoutRefresh() {
        return this.tree;
    }

    /**
     * @throws ComponentException
     */
    private void loadComponents() throws ComponentException {
        // XXX need to use wsdlResolver from xsul, not xsul5, to handle
        // security.
        WsdlResolver wsdlResolver = WsdlResolver.getInstance();
        WsdlDefinitions definitions = wsdlResolver.loadWsdl(this.url);
        List<WSComponent> components = WSComponentFactory
                .createComponents(WSDLUtil
                        .wsdlDefinitions3ToWsdlDefintions5(definitions));
        String urlString = this.url.toString();
        String name = urlString.substring(urlString.lastIndexOf('/') + 1);
        URLComponentReference componentReference = new URLComponentReference(
                name, components);
        ComponentTreeNode treeLeaf = new ComponentTreeNode(componentReference);
        this.tree.add(treeLeaf);
    }
}

/*
 * Indiana University Extreme! Lab Software License, Version 1.2
 * 
 * Copyright (c) 2007 The Trustees of Indiana University. All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 * 
 * 1) All redistributions of source code must retain the above copyright notice,
 * the list of authors in the original source code, this list of conditions and
 * the disclaimer listed in this license;
 * 
 * 2) All redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the disclaimer listed in this license in
 * the documentation and/or other materials provided with the distribution;
 * 
 * 3) Any documentation included with all redistributions must include the
 * following acknowledgement:
 * 
 * "This product includes software developed by the Indiana University Extreme!
 * Lab. For further information please visit http://www.extreme.indiana.edu/"
 * 
 * Alternatively, this acknowledgment may appear in the software itself, and
 * wherever such third-party acknowledgments normally appear.
 * 
 * 4) The name "Indiana University" or "Indiana University Extreme! Lab" shall
 * not be used to endorse or promote products derived from this software without
 * prior written permission from Indiana University. For written permission,
 * please contact http://www.extreme.indiana.edu/.
 * 
 * 5) Products derived from this software may not use "Indiana University" name
 * nor may "Indiana University" appear in their name, without prior written
 * permission of the Indiana University.
 * 
 * Indiana University provides no reassurances that the source code provided
 * does not infringe the patent or any other intellectual property rights of any
 * other entity. Indiana University disclaims any liability to any recipient for
 * claims brought by any other entity based on infringement of intellectual
 * property rights or otherwise.
 * 
 * LICENSEE UNDERSTANDS THAT SOFTWARE IS PROVIDED "AS IS" FOR WHICH NO
 * WARRANTIES AS TO CAPABILITIES OR ACCURACY ARE MADE. INDIANA UNIVERSITY GIVES
 * NO WARRANTIES AND MAKES NO REPRESENTATION THAT SOFTWARE IS FREE OF
 * INFRINGEMENT OF THIRD PARTY PATENT, COPYRIGHT, OR OTHER PROPRIETARY RIGHTS.
 * INDIANA UNIVERSITY MAKES NO WARRANTIES THAT SOFTWARE IS FREE FROM "BUGS",
 * "VIRUSES", "TROJAN HORSES", "TRAP DOORS", "WORMS", OR OTHER HARMFUL CODE.
 * LICENSEE ASSUMES THE ENTIRE RISK AS TO THE PERFORMANCE OF SOFTWARE AND/OR
 * ASSOCIATED MATERIALS, AND TO THE PERFORMANCE AND VALIDITY OF INFORMATION
 * GENERATED USING SOFTWARE.
 */
